@@ -40,6 +40,9 @@ def notify_user_via_mail(
             id = user
 
         mailto = find_mail_from_user_id(qrs, id)
+        if not mailto:
+            logging.error("Missing email address for user: " + user)
+            mailto = mail_cc
     send_mail(mail_smtp, mail_from, mailto, mail_subject, message, mail_cc, mail_bcc)
 
 
